California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 22 - 2000 DEFINITION OF MARRIAGE. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
990319 | YES ON PROP. 22 - CALIFORNIANS FOR PROTECTION OF MARRIAGE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
990089 | NO ON KNIGHT - NO ON PROP. 22 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
982936 | DEFENSE OF MARRIAGE CAMPAIGN - YES ON PROP. 22, A SPECIAL PROJECT OF COMMITTEE ON MORAL CONCERNS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991792 | STUDENT ALLIANCE FOR FAIRNESS AND EQUALITY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
990715 | NO ON KNIGHT-COMMITTEE AGAINST THE KNIGHT INITIATIVE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220887 | SAN FRANCISCO FOUNDATION COMMUNITY INITIATIVE FUNDS ANTI-DISCRIMINATION EDUCATION COMMITTEE AGAINST PROPOSITION 22, THE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1219956 | CONCERNED CITIZENS AGAINST PROPOSITION 22 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992349 | AMERICAN FRIENDS SERVICE COMMITTEE AGAINST PROP. 22 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1221066 | AMERICA NEEDS FATIMA COMMITTEE IN FAVOR OF PROPOSITION 22, SPONSORED BY THE FOUNDATION FOR A CHRISTIAN CIVILIZATION, INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1220851 | BUSINESS LEADERS AGAINST PREJUDICE, A COMMITTEE AGAINST PROPOSITION 22 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1221889 | NATIONAL GAY AND LESBIAN TASK FORCE, INC. | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
981204 | CALIFORNIANS FOR THE DEFENSE OF MARRIAGE, A COMMITTEE FOR PROP. 22 | SUPPORT